@@ -29,7 +29,7 @@ public:
 
     // other functions
     int SetEOF();
-    unsigned char * GetBuffer(int *) { return NULL; }
+    unsigned char * GetBuffer(int *) { return APE_NULL; }
 
     // creation / destruction
     int Create(const wchar_t * pName);
